split_lines

Function split_lines 

pub fn split_lines(code: &str) -> impl Iterator<Item = &str>
Splits source exactly as the highlighter does, preserving an empty source line while omitting the synthetic line after a trailing newline.